@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
@@ -21,8 +21,8 @@ import (
 	"context"
 	"errors"
 
-	"git.zabbix.com/ap/plugin-support/zbxerr"
 	"github.com/jackc/pgx/v4"
+	"golang.zabbix.com/sdk/zbxerr"
 )
 
 // autovacuumHandler returns count of autovacuum workers if all is OK or nil otherwise.
@@ -32,7 +32,7 @@ func autovacuumHandler(ctx context.Context, conn PostgresClient,
 
 	query := `SELECT count(*)
 				FROM pg_catalog.pg_stat_activity
-			   WHERE query like '%%autovacuum%%'
+				WHERE backend_type = 'autovacuum worker'
 				 AND state <> 'idle'
 				 AND pid <> pg_catalog.pg_backend_pid()`
 
